@@ -1603,6 +1603,8 @@ function xmldb_main_upgrade($oldversion) {
     }
 
     if ($oldversion < 2013021801.01) {
+        // This upgrade step is re-written under MDL-38228 (see below).
+        /*
         // Retrieve the list of course_sections as a recordset to save memory
         $coursesections = $DB->get_recordset('course_sections', null, 'course, id', 'id, course, sequence');
         foreach ($coursesections as $coursesection) {
@@ -1646,6 +1648,7 @@ function xmldb_main_upgrade($oldversion) {
             }
         }
         $coursesections->close();
+        */
 
         // Main savepoint reached.
         upgrade_main_savepoint(true, 2013021801.01);
@@ -1696,6 +1699,9 @@ function xmldb_main_upgrade($oldversion) {
     // This is checking to see if the site has been running a specific version with a bug in it
     // because this upgrade step is slow and is only needed if the site has been running with the affected versions.
     if ($oldversion >= 2012062504.08 && $oldversion < 2012062504.13) {
+        // This upgrade step is re-written under MDL-38228 (see below).
+
+        /*
         // Retrieve the list of course_sections as a recordset to save memory.
         // This is to fix a regression caused by MDL-37939.
         // In this case the upgrade step is fixing records where:
@@ -1754,6 +1760,7 @@ function xmldb_main_upgrade($oldversion) {
         $coursesections->close();
 
         // No savepoint needed for this change.
+         */
     }
 
     if ($oldversion < 2013032200.01) {
@@ -2191,5 +2198,74 @@ function xmldb_main_upgrade($oldversion) {
         upgrade_main_savepoint(true, 2013051401.01);
     }
 
+    if ($oldversion < 2013051402.06) {
+        // Fixing possible wrong MIME type for Java Network Launch Protocol (JNLP) files.
+        $select = $DB->sql_like('filename', '?', false);
+        $DB->set_field_select(
+            'files',
+            'mimetype',
+            'application/x-java-jnlp-file',
+            $select,
+            array('%.jnlp')
+        );
+
+        // Main savepoint reached.
+        upgrade_main_savepoint(true, 2013051402.06);
+    }
+
+    if ($oldversion < 2013051402.10) {
+        // Find all fileareas that have missing root folder entry and add the root folder entry.
+        if (empty($CFG->filesrootrecordsfixed)) {
+            $sql = "SELECT distinct f1.contextid, f1.component, f1.filearea, f1.itemid
+                FROM {files} f1 left JOIN {files} f2
+                    ON f1.contextid = f2.contextid
+                    AND f1.component = f2.component
+                    AND f1.filearea = f2.filearea
+                    AND f1.itemid = f2.itemid
+                    AND f2.filename = '.'
+                    AND f2.filepath = '/'
+                WHERE (f1.component <> 'user' or f1.filearea <> 'draft')
+                and f2.id is null";
+            $rs = $DB->get_recordset_sql($sql);
+            $defaults = array('filepath' => '/',
+                            'filename' => '.',
+                            'userid' => $USER->id,
+                            'filesize' => 0,
+                            'timecreated' => time(),
+                            'timemodified' => time(),
+                            'contenthash' => sha1(''));
+            foreach ($rs as $r) {
+                $pathhash = sha1("/$r->contextid/$r->component/$r->filearea/$r->itemid".'/.');
+                $DB->insert_record('files', (array)$r + $defaults +
+                        array('pathnamehash' => $pathhash));
+            }
+            $rs->close();
+            // To skip running the same script on the upgrade to the next major release.
+            set_config('filesrootrecordsfixed', 1);
+        }
+
+        // Main savepoint reached.
+        upgrade_main_savepoint(true, 2013051402.10);
+    }
+
+    if ($oldversion < 2013051402.12) {
+        // MDL-38228. Corrected course_modules upgrade script instead of 2013021801.01.
+
+        // This upgrade script fixes the mismatches between DB fields course_modules.section
+        // and course_sections.sequence. It makes sure that each module is included
+        // in the sequence of only one section and that course_modules.section points back to it.
+
+        // This script in included in each major version upgrade process so make sure we don't run it twice.
+        if (empty($CFG->movingmoduleupgradescriptwasrun)) {
+            upgrade_course_modules_sequences();
+
+            // To skip running the same script on the upgrade to the next major release.
+            set_config('movingmoduleupgradescriptwasrun', 1);
+        }
+
+        // Main savepoint reached.
+        upgrade_main_savepoint(true, 2013051402.12);
+    }
+
     return true;
 }
