@@ -646,7 +646,7 @@ $string['randomwithsubcat'] = 'Questions from this category and its subcategorie
 $string['readytosend'] = 'You are about to send your whole quiz to be graded.  Are you sure you want to continue?';
 $string['reattemptquiz'] = 'Re-attempt quiz';
 $string['recentlyaddedquestion'] = 'Recently added question!';
-$string['recurse'] = 'Include questions from sub-categories too';
+$string['recurse'] = 'Include questions from subcategories too';
 $string['regrade'] = 'Regrade all attempts';
 $string['regradecomplete'] = 'All attempts have been regraded';
 $string['regradecount'] = '{$a->changed} out of {$a->attempt} grades were changed';
